Skip to contents

Returns a summary of global network characteristics of the language network.

Usage

get_network_info(network)

Arguments

network

An igraph network object, generated by make_network() or make_network_sep() functions.

Value

A named vector of global network metrics. For more information about these metrics, refer to the package vignette.

Examples

#' # Use the demo data for executing examples

  test <- make_network(sample1)
#> 
  |                                                                            
  |                                                                      |   0%
  |                                                                            
  |========                                                              |  11%
  |                                                                            
  |================                                                      |  22%
  |                                                                            
  |=======================                                               |  33%
  |                                                                            
  |===============================                                       |  44%
  |                                                                            
  |=======================================                               |  56%
  |                                                                            
  |===============================================                       |  67%
  |                                                                            
  |======================================================                |  78%
  |                                                                            
  |==============================================================        |  89%
  get_network_info(network = test)
#>          nodes          edges           ASPL      global CC        mean CC 
#>          9.000          9.000          1.821          0.273          0.267 
#>       diameter    mean degree no. components   prop. in LCC 
#>          3.000          2.000          2.000          0.889